<?php

/**
 * Openfed Social settings form.
 */
function ofed_social_admin_form() {
  // We'll create a multichoice selection table, sortable, with several social
  // networks. A theme selection field will also be added to support a smooth
  // migration from a sharethis solution to Openfed Social.
  $networks = ofed_social_get_options_array();
  $networks_enabled = variable_get('ofed_social_networks_enabled',array());
  $options = $enabled = array();
  $counter = 0;
  $form['weight'] = array('#tree' => TRUE);
  foreach ($networks as $network_key => $network_values) {
    $options[$network_key] = $network_key;
    if (isset($networks_enabled[$network_key])) {
      $enabled[] = $network_key;
    }
    $form['weight'][$network_key] = array(
      '#type' => 'weight',
      '#title' => t('Weight for @title', array('@title' => $network_values['label'])),
      '#title_display' => 'invisible',
      '#default_value' => $counter,
      '#attributes' => array('class' => array('social-networks-order-weight')),
    );
    $form['name'][$network_key] = array('#markup' => check_plain($network_values['label']));
    $form['labels'][$network_key] = array('#type' => 'hidden', '#value' => $network_values['label']);
    $counter ++;
  }
  $form['enabled'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Enabled Social Networks'),
    '#title_display' => 'invisible',
    '#options' => $options,
    '#default_value' => $enabled,
  );

  $theme_options = array(
    'default' => 'Default',
    'small'=>'Small icons',
    'large' =>  'Large icons',
    'custom' => 'Custom icons',
  );
  $form['theme'] = array(
    '#type' => 'radios',
    '#title' => t('Theme to use to render the social links.'),
    '#options' => $theme_options,
    '#default_value' => variable_get('ofed_social_theme_links', 'default'),
  );
  $form['use_sharethis_theme'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use ShareThis HTML elements and classes.'),
    '#default_value' => variable_get('ofed_social_use_sharethis_theme', 1),
  );
  $form['use_sharethis_chicklets'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use ShareThis chicklets.'),
    '#description' => t('This will print a <span> with old Sharethis classes instead of printing Openfed Social SVG files.'),
    '#default_value' => variable_get('ofed_social_use_sharethis_chicklets', 0),
    '#states' => array(
      'enabled' => array(
        ':input[name="use_sharethis_theme"]' => array('checked' => true),
      ),
    ),
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array('#type' => 'submit', '#value' => t('Save configuration'));
  $form['#theme'] = 'ofed_social_admin_form';

  return $form;
}

/**
 * Returns HTML to create the sortable multiselect table.
 *
 * @param $variables
 *   An associative array containing:
 *   - form: A render element representing the form.
 *
 * @ingroup themeable
 */
function theme_ofed_social_admin_form($variables) {
  $rows = array();
  $form = $variables['form'];
  foreach ($form['name'] as $key => $element) {
    // Do not take form control structures.
    if (is_array($element) && element_child($key)) {
      // Add invisible labels for the checkboxes and radio buttons in the table
      // for accessibility. These changes are only required and valid when the
      // form is themed as a table, so it would be wrong to perform them in the
      // form constructor.
      $title = drupal_render($form['name'][$key]);
      $form['enabled'][$key]['#title'] = t('Enable !title', array('!title' => $title));
      $form['enabled'][$key]['#title_display'] = 'invisible';
      $form['site_default'][$key]['#title'] = t('Set !title as default', array('!title' => $title));
      $form['site_default'][$key]['#title_display'] = 'invisible';
      $rows[] = array(
        'data' => array(
          '<strong>' . $title . '</strong>',
          array('data' => drupal_render($form['enabled'][$key])),
          drupal_render($form['weight'][$key]),
        ),
        'class' => array('draggable'),
      );
    }
  }
  $header = array(array('data' => t('Network')), array('data' => t('Enabled')), array('data' => t('Weight')));
  $output = theme('table', array('header' => $header, 'rows' => $rows, 'attributes' => array('id' => 'social-networks-order')));
  $output .= drupal_render_children($form);
  drupal_add_tabledrag('social-networks-order', 'order', 'sibling', 'social-networks-order-weight');
  return $output;
}

/**
 * Process Openfed Social settings form submissions, updating existing variables.
 */
function ofed_social_admin_form_submit($form, &$form_state) {
  $submissions = $form_state['values'];
  $existing_networks_settings = ofed_social_get_options_array();
  $networks = $networks_enabled = array();
  // Sorting by weight will ensure the right order when saving the variable.
  asort($submissions['weight']);
  foreach ($submissions['weight'] as $network_key => $weight) {
    // We'll add an extra variable so we can easily get the enabled networks.
    if ($submissions['enabled'][$network_key]) {
      $networks_enabled[$network_key] = array(
        'label' => $submissions[$network_key],
      );
    }
    // We've to update the full network list with the current sort order.
    $networks[$network_key] = $existing_networks_settings[$network_key];
  }
  variable_set('ofed_social_theme_links', $submissions['theme']);
  variable_set('ofed_social_use_sharethis_theme', $submissions['use_sharethis_theme']);
  variable_set('ofed_social_use_sharethis_chicklets', $submissions['use_sharethis_chicklets']);
  variable_set('ofed_social_networks_enabled', $networks_enabled);
  variable_set('ofed_social_networks', $networks);
  drupal_set_message(t('Configuration saved.'));
  return;
}
